%ifnarch %{ocaml_native_compiler}
%global debug_package %{nil}
%endif

%global srcname merlin

Name:           ocaml-%{srcname}
Version:        3.5.0
Release:        1%{?dist}.rvre2
Summary:        Context sensitive completion for OCaml

# The entire source is MIT except:
# - QPL: src/ocaml/driver/pparse.ml{,i}
# - QPL: src/ocaml/preprocess/lexer_ident.mll
# - QPL: src/ocaml/preprocess/lexer_raw.ml{i,l}
# - LGPLv2 with exceptions: src/ocaml/preprocess/parser_raw.mly
# - LGPLv2 with exceptions: upstream/ocaml_411/parsing/parser.mly
# - LGPLv2 with exceptions: upstream/ocaml_412/parsing/parser.mly
#
# The final license is due to the linking exception on the LGPLv2 files.
License:        MIT and QPL
URL:            https://ocaml.github.io/%{srcname}/
Source0:        https://github.com/ocaml/%{srcname}/releases/download/v%{version}/%{srcname}-v%{version}.tbz
# Fix the tests to work with /usr/lib64 as well as /usr/lib
Patch0:         %{name}-test-lib64.patch
# Fix various issues in the Emacs interface
Patch1:         %{name}-emacs.patch
# Adapt a test that fails only on Fedora with OCaml 4.11.
# It passes with OCaml 4.12, and on non-Fedora systems ... because the ocaml
# .cmti files are missing?
Patch2:         %{name}-fedora.patch
# On i386, we get extra output about text relocations
# See https://github.com/ocaml/ocaml/issues/9800
Patch3:         %{name}-textrel.patch

BuildRequires:  emacs
BuildRequires:  emacs-tuareg
BuildRequires:  jq
BuildRequires:  ocaml >= 4.02.1
BuildRequires:  ocaml-biniou-devel
BuildRequires:  ocaml-csexp-devel >= 1.2.3
BuildRequires:  ocaml-dune >= 1.8.0
BuildRequires:  ocaml-easy-format-devel
BuildRequires:  ocaml-findlib-devel >= 1.6.0
BuildRequires:  ocaml-menhir
BuildRequires:  ocaml-result-devel >= 1.5
BuildRequires:  ocaml-yojson-devel >= 1.6.0
BuildRequires:  vim-enhanced

Requires:       emacs-filesystem >= %{?_emacs_version}%{!?_emacs_version:0}
Requires:       vim-filesystem

%description
Merlin is an assistant for editing OCaml code. It aims to provide the features
available in modern IDEs: error reporting, auto completion, source browsing and
much more.


%prep
%autosetup -n %{srcname}-v%{version} -N
%patch0 -p1
%patch1 -p1
%patch2 -p1
%ifarch %{ix86}
%patch3 -p1
%endif


%build
dune build %{_smp_mflags}


%install
dune install --destdir=%{buildroot}

# We do not want the ml files
find %{buildroot}%{_libdir}/ocaml -name \*.ml -delete

# We install the documentation with the doc macro
rm -fr %{buildroot}%{_prefix}/doc

# Reinstall vim files to Fedora default location
mkdir -p %{buildroot}%{vimfiles_root}
mv %{buildroot}%{_datadir}/%{srcname}/vim/* %{buildroot}%{vimfiles_root}
rm -fr %{buildroot}%{_datadir}/%{srcname}

# Generate the autoload file for the Emacs interface and byte compile
# Add fake provides due to missing dependencies in F33
cd %{buildroot}%{_emacs_sitelispdir}
emacs -batch --no-init-file --no-site-file \
  --eval "(progn (setq generated-autoload-file \"$PWD/merlin-autoloads.el\" backup-inhibited t) (update-directory-autoloads \".\"))"
mkdir -p %{buildroot}%{_emacs_sitestartdir}
mv merlin-autoloads.el %{buildroot}%{_emacs_sitestartdir}
emacs -batch --no-init-file --no-site-file \
  --eval '(progn (provide (quote auto-complete)) (provide (quote company)) (provide (quote iedit)) (setq load-path (cons "." load-path)))' \
  -f batch-byte-compile *.el
cd -


%check
# Test requirement is not satisfied in Fedora


%files
%doc doc/* featuremap.* README.md CHANGES.md
%license LICENSE
%{_bindir}/dot-merlin-reader
%{_bindir}/ocamlmerlin
%{_bindir}/ocamlmerlin-server
%{_libdir}/ocaml/%{srcname}/
%{_libdir}/ocaml/dot-merlin-reader/
%{_emacs_sitelispdir}/merlin*
%{_emacs_sitestartdir}/merlin-autoloads.el
%{vimfiles_root}/*/*


%changelog
* Sun Apr 25 2021 David Abdurachmanov <david.abdurachmanov@sifive.com> - 3.5.0-1.rvre2
- Rebuilt for Fedora RISCV, no changes

* Sun Apr 25 2021 David Abdurachmanov <david.abdurachmanov@sifive.com> - 3.5.0-1.rvre1
- Rebuilt for Fedora RISCV, no changes

* Sun Apr 25 2021 David Abdurachmanov <david.abdurachmanov@sifive.com> - 3.5.0-1.rvre0
- Rebuilt for Fedora RISCV, no changes

* Wed Apr 14 2021 Jerry James <loganjerry@gmail.com> - 3.5.0-1
- Version 3.5.0
- Fix tests on 64-bit systems with the -test-lib64 patch
- Add -emacs patch to fix various Emacs issues
- Add -textrel patch to fix FTBFS on i386
- Generate autoloads for the Emacs interface

* Wed Sep 02 2020 Richard W.M. Jones <rjones@redhat.com> - 3.3.7-0.3.preview1.1
- Bump release and rebuild.

* Tue Sep 01 2020 Richard W.M. Jones <rjones@redhat.com> - 3.3.7-0.3.preview1
- OCaml 4.11.1 rebuild

* Fri Aug 21 2020 Richard W.M. Jones <rjones@redhat.com> - 3.3.7-0.2.preview1
- OCaml 4.11.0 rebuild

* Fri Aug  7 2020 Robin Lee <cheeselee@fedoraproject.org> - 3.3.7-0.1.preview1
- Update to 3.3.7-preview1

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 3.3.4-3
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 3.3.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Sat Apr 18 2020 Robin Lee <cheeselee@fedoraproject.org> - 3.3.4-1
- Update to 3.3.4 final

* Tue Mar  3 2020 Robin Lee <cheeselee@fedoraproject.org> - 3.3.4-0.1.preview1
- Update to 3.3.4-preview1, supports OCaml 4.10 (BZ#1799817, BZ#1809312)

* Wed Jan 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 3.3.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Sun Dec  1 2019 Robin Lee <cheeselee@fedoraproject.org> - 3.3.3-1
- Release 3.3.3 (RHBZ#1778280)
- Fix Release tag (RHBZ#1777835)

* Sat Aug  3 2019 Robin Lee <cheeselee@fedoraproject.org> - 3.3.2-1
- Update to 3.3.2

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 3.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri Jun 28 2019 Robin Lee <cheeselee@fedoraproject.org> - 3.3.1-1
- Update to 3.3.1 (BZ#1703452)

* Sun Mar 31 2019 Robin Lee <cheeselee@fedoraproject.org> - 3.2.2-2
- Fix ocaml library path

* Fri Mar  1 2019 Robin Lee <cheeselee@fedoraproject.org> - 3.2.2-1
- Initial packaging
